<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>(%1) 닫기</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>접기</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>펼치기</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>알림 해제</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>단어 %Ln개</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln 분</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%Ln 분 중 %L1%</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation>
            <numerusform>단어 %Ln 중 %L1%</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>하루 작업량</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>가장 긴 연속 작업</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>현재 연속 작업</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>없음</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n 일</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;n회당; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation>하루 목표의 %L1% </translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>언어 설정</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(제목없음 %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (읽기 전용)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>죄송합니다</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>&apos;%1&apos; 파일을 저장할 수 없습니다.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>다른 이름으로 저장</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>&apos;%1&apos; 파일을 덮어쓸 수 없습니다.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>파일 이름 바꾸기</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>&apos;%1&apos; 파일의 이름을 바꿀 수 없습니다.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>파일을 다시 불러올까요?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>디스크에서 &apos;%1&apos; 파일을 다시 불러올까요?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>저장하지 않은 바뀐 정보는 사라집니다.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>새로 고침</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>제목없음 %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>물어볼 것이 있습니다.</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>일반 텍스트로 저장하면 모든 서식을 잃어버리게 됩니다. 서식을 버리시겠습니까?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>파일 변환 완료</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>&apos;%1&apos; 파일이 다른 프로그램에 의해서 변경되었습니다.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>파일을 다시 불러올까요?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>새로 고침</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>그대로 둠</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>파일을 지웠습니다.</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>%1 파일이 다른 프로그램에 의해서 지워졌습니다.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>파일을 저장할까요? 닫을까요?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>압축파일을 열 수 없습니다.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>검색 :</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>다음과 바꿈 :  </translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>대/소문자 구분 안함</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>단어로 검색</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>일반적인 표현</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>위로 검색</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>아래로 검색</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>찾기</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>바꾸기</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>모두 바꾸기</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>찾기</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>바꾸기</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>%n 의 사례를 바꿀까요?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>물어볼 것이 있습니다</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>죄송합니다</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>문장이 없습니다.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>오픈 다큐먼트 텍스트</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>오피스 오픈 XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>서식 있는 텍스트</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>일반 텍스트</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>모든 파일</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>모든 지원되는 파일</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>오픈도큐먼트 플랫 XML</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>더하기</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>맞춤법 검사 하기...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(다른 대안을 찾지 못했습니다)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>이미지 열기</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>이미지</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>프로그램 언어 선택:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt; 시스템 언어 &gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>노트</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>바뀐 언어로 적용하기 위해 프로그램을 다시 시작 해주세요.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>압축파일을 열 수 없습니다.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>설정</translation>
    </message>
    <message>
        <source>General</source>
        <translation>일반 설정</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>통계</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>툴바</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>맞춤법 검사</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>사전 고르기</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>죄송합니다</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>압축파일을 열 수 없습니다.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>이용할 만 한 사전이 없습니다.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>물어볼 것이 있습니다</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>단축키</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>하나 이상의 단축키에서 충돌이 났습니다. 계속할까요?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>사전 &quot;%1&quot; 은 이미 있습니다. 바꾸시겠습니까?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>오늘의 목표</translation>
    </message>
    <message>
        <source>None</source>
        <translation>없음</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>분:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>단어:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>설정하기</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>항상 세로로 가운데 맞춤</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>블럭 삽입 커서</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>부드러운 글꼴</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>타자기 소리</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>지능형 따옴표:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>큰 따옴표</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>작은 따옴표</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>화면</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>구분선:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>저장하기</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>커서 위치 저장하기</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>단어 수</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>페이지 수</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>문단 수</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>글자 수</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>글자:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>문단:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>단어 수 세는 알고리즘</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>오늘의 하루 작업량을 0으로 초기화할까요?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>일반 텍스트 파일에 바이트 순서 표식을 사용합니다.</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>기본 포맷:</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>오늘 기록 초기화</translation>
    </message>
    <message>
        <source>History</source>
        <translation>기록</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>기록 저장하기</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>연속 기록 보이기</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>연속 작업대비 최소 작업비:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>단어의 범위를 감지하기</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>글자 수를 여섯 개마다 나누기 </translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>각 문자를 단어로 세기</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>페이지 수 세는 알고리즘</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>스타일</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>아이콘만 사용</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>텍스트만 사용</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>아이콘 옆에 글자 표시</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>아이콘 아래에 글자 표시</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>텍스트 위치:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>기능</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>위로 옮기기</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>아래로 옮기기</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>구분선 더하기</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>명령어</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>단축키</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>기능</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>입력하는 대로 검사하기</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>대문자 건너뛰기</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>숫자 건너뛰기</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>언어</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>더하기</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>제거</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>개인 사전</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>이 사전을 지울까요?</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>사용자 인터페이스</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>스크롤바 항상 보이기</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>제목 줄 항상 보이기</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>내용 표시 줄 항상 보이기</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>지원하는 RTF 파일이 아닙니다.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>예상과 달리 파일끝에 닿았습니다.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Down</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>화면을 위로 올리기</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Up</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>화면 목록 켜고/끄기</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>(%1) 화면 목록 보이기</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>(%1) 화면 목록 감추기</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>필터</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>화면을 아래로 내리기</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>화면 목록 크기 조절</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>기본 세션</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>세션 관리</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>세션</translation>
    </message>
    <message>
        <source>New</source>
        <translation>새로 만들기</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>복사하기</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>이름 바꾸기</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>지우기</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>서로 바꾸기</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>새 세션</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>세션 복사</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>세션 이름 바꾸기</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>물어볼 것이 있습니다</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>선택한 세션을 지우시겠습니까?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>세션 이름</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>죄송합니다.</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>요청하신 세션 이름은 이미 사용 중입니다.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>새로 만들기...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>관리하기...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>지우기</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>기본 설정으로 되돌리기</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>단축키:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>따옴표 바꾸기...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>기다려 주세요</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>맞춤법 검사</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>더하기</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>그대로 둠</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>모두 그대로 둠</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>바꾸기</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>모두 바꿈</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>이 사전엔 없습니다 :</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>다음으로 바꾸기:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>맞춤법 검사 중입니다...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소하기</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>기다려 주세요</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>파일의 처음부터 다시 체크하시겠습니까?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>맞춤법 검사를 마쳤습니다.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>부호</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>최근에 사용한 부호들</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>모든 부호들</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>크게 보기</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>이름:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>적용</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>블록</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>스크립트</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>제목 없음 %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>이름:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>이미지 없음</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>타일 붙임</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>가운데 맞춤</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>늘이기</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>비율 맞춤</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>확대 맞춤</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>불투명도:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>위치:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>너비:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>노트 모서리 둥금 정도</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>반경:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>노트 배경 흐릿함 정도</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>노트 그림자 정도</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>아래로 옮김 정도:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>글자와 노트 사이의 사이띄기</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>창과의 거리:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>노트와 글자와의 거리:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>한 줄 들여쓰기</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>위로:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>아래로:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>지우기</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>테마 편집</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>배경 그림 설정</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>종류</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>색상</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>이미지</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation>pixels</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>왼쪽</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>노트 설정</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>오른쪽</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>글자</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>글꼴:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>오자 표시:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>줄 띄우기</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>한 줄</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1.5 줄</translation>
    </message>
    <message>
        <source>Double</source>
        <translation> 두 줄</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>비율 맞춤</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>줄 높이:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>문단 사이 띄기</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>탭 너비:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>새로운 테마</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>테마</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>기본 세션</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>편한 푸른색</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>올드 스쿨</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>스페이스 드림</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>나무 책상</translation>
    </message>
    <message>
        <source>New</source>
        <translation>새로 만들기</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>복사하기</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>사용자 설정</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>편집하기</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>지우기</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>가져오기</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>내보내기</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>물어볼 것이 있습니다.</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>&apos;%1&apos; 테마를 지우시겠습니까?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>테마 (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>테마 가져오기</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>테마 내보내기</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>비터 스카이</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>마법</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>스파이 게임</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>고요</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>물어볼 것이 있습니다.</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>타이머를 지울까요?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;단어:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;페이지:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;문단:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;글자:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>지연 시간 설정</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>시간 설정</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>지연 시간:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>시간:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>시:분:초</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>알람</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>종류:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>메모:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>수정</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>지우기</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>시:분:초</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>타이머 작동 안함</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>타이머</translation>
    </message>
    <message>
        <source>New</source>
        <translation>새로 만들기</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>최근 설정</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>물어볼 것이 있습니다.</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>타이머 수정을 취소할까요?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+시:분:초</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>테마 불러오는 중</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>효과음 불러오는 중</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>제목 없음</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>파일 열기</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>포커스 라이터 란</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>포커스 라이터</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>간편한 풀스크린 워드 프로세서</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation> &lt;a href=%1&gt;GPL 3&lt;/a&gt; 라이선스에 따라 배포됩니다.</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>&lt;a href=%1&gt;Oxygen&lt;/a&gt;의 아이콘 테마를 이용합니다.</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>&lt;a href=%1&gt;LGPL 3&lt;/a&gt; 의 라이선스를 준수합니다.</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>문자: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>페이지: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>문단: % L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>단어: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>%1 열기</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(제목없음 %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>모든 문서 보이기</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>다음 문서로 이동</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>이전 문서로 이동</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>처음 문서로 이동</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>마지막 문서로 이동</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>%1 문서로 이동</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>설정 불러오는 중</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>비상 캐시가 작성되지 않습니다.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>알림</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>포커스 라이터가 제대로 꺼지지 않았습니다.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>비상 캐시를 이용해서 복구할까요?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>몇몇 파일들이 열리지 않습니다.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>몇몇 파일들이 일기 전용으로 열렸습니다.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; 이 캐시에 복사된 것보다 새것입니다.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>새 파일로 덮어쓸까요?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>바뀐 내용을 저장하시겠습니까?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>닫기 전에 파일 &apos;%1&apos;에 바뀐 내용을 저장하시겠습니까?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>저장하지 않으시면 바뀐 내용을 잃어버리십니다.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>타자기 효과음을 불러올 수 없습니다.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>파일</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>새로 만들기</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>열기...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>새로 고침</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>저장</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>다른 이름으로 저장...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>이름 바꾸기...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>모두 저장하기</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>세션 관리하기</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>새 세션</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>출력하기...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>닫기</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>끝내기</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>편집</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>뒤로 무르기</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>다시 적용</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>자르기</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>복사하기</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>붙여넣기</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>서식을 유지한 채 붙여넣기</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>모두 선택</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>화면 선택</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>양식</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>볼드</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>이탤릭</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>밑줄 긋기</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>가운데 줄긋기</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>위 첨자</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>아래 첨자</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>왼쪽 끝 맞춤</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>가운데 줄맞춤</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>오른쪽 끝 맞춤</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>양끝 맞춤</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>들여 쓰기</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>내어 쓰기</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>왼쪽에서 오른쪽으로 쓰기 시작</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>오른쪽에서 왼쪽으로 쓰기 시작</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>도구</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>찾아보기...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>다음에서 찾기</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>이전에서 찾기</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>바꾸기...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>지능형 따옴표</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>문서에 적용</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>선택한 내용 적용</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>맞춤법...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>언어 설정...</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>타이머...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>부호들...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>하루 진행량</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>툴바 보이기</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>메뉴 아이콘 보이기</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>포커스 텍스트</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>전체 화면</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>최소화</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>테마...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>설정...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>포커스 끔</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>한 줄 포커스 </translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>세 줄 포커스 </translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>문단</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>문단 포커스 </translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>도움말</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>프로그램 언어 설정...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>지원되지 않는 파일이 있어서 열 수 없습니다.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>사용 안함</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>한 줄</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>세 줄</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>FocusWriter 소개</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Qt 소개</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>쪽 설정...</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>머릿글</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>머릿글 &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>머릿글 &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>머릿글 &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>머릿글 &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>머릿글 &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>머릿글 &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>기본</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>지능형 따옴표 문서에 적용</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>선택한 내용에 지능형 따옴표 적용</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Shift+`</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Files to open in current session.</source>
        <translation>현제 세션에서 열 파일</translation>
    </message>
</context>
</TS>
